Improve this Doc

# Error: $interpolate:reqopenbrace
An opening brace was expected but not found

    The plural choice “{0}” must be followed by a message in braces at line {1}, column {2} in text “{3}”

## Description

The plural or select extension keyword or values (such as "other", "male", "female", "=0", "one", "many", etc.) MUST be followed by a message enclosed in braces.

For more information about the MessageFormat syntax in interpolation expressions, please refer to MessageFormat extensions section at Angular i18n MessageFormat